home | help
GMX-GROMPP(1)			     GROMACS			   GMX-GROMPP(1)

NAME
     gmx-grompp - Make a run input file

SYNOPSIS
	gmx grompp [-f [<.mdp>]] [-c [<.gro/.g96/...>]] [-r [<.gro/.g96/...>]]
		   [-rb [<.gro/.g96/...>]] [-n [<.ndx>]] [-p [<.top>]]
		   [-t [<.trr/.cpt/...>]] [-e [<.edr>]] [-qmi [<.inp>]]
		   [-ref [<.trr/.cpt/...>]] [-po [<.mdp>]] [-pp [<.top>]]
		   [-o [<.tpr>]] [-imd [<.gro>]] [-[no]v] [-time <real>]
		   [-[no]rmvsbds] [-maxwarn <int>] [-[no]zero] [-[no]renum]

DESCRIPTION
     gmx  grompp  (the	gromacs  preprocessor)	reads a molecular topology file,
     checks the validity of the file, expands the topology from a molecular  de-
     scription	to an atomic description. The topology file contains information
     about molecule types and the number of molecules, the  preprocessor  copies
     each  molecule as needed.	There is no limitation on the number of molecule
     types.  Bonds and bond-angles can be converted into constraints, separately
     for hydrogens and heavy atoms.  Then a coordinate file is read and  veloci-
     ties  can	be  generated  from a Maxwellian distribution if requested.  gmx
     grompp also reads parameters for gmx mdrun (eg. number of	MD  steps,  time
     step, cut-off).  Eventually a binary file is produced that can serve as the
     sole input file for the MD program.

     gmx  grompp  uses	the atom names from the topology file. The atom names in
     the coordinate file (option -c) are only read  to	generate  warnings  when
     they do not match the atom names in the topology.	Note that the atom names
     are  irrelevant for the simulation as only the atom types are used for gen-
     erating interaction parameters.

     gmx grompp uses a built-in preprocessor to resolve includes,  macros,  etc.
     The preprocessor supports the following keywords:

	#ifdef VARIABLE
	#ifndef VARIABLE
	#else
	#endif
	#define VARIABLE
	#undef VARIABLE
	#include "filename"
	#include <filename>

     The  functioning  of  these statements in your topology may be modulated by
     using the following two flags in your .mdp file:

	define = -DVARIABLE1 -DVARIABLE2
	include = -I/home/john/doe

     For further information a C-programming textbook may help you out.   Speci-
     fying  the -pp flag will get the pre-processed topology file written out so
     that you can verify its contents.

     When using position restraints, a file with restraint coordinates	must  be
     supplied with -r (can be the same file as supplied for -c). For free energy
     calculations, separate reference coordinates for the B topology can be sup-
     plied with -rb, otherwise they will be equal to those of the A topology.

     Starting  coordinates  can be read from trajectory with -t.  The last frame
     with coordinates and velocities will be read, unless the  -time  option  is
     used.  Only  if  this  information is absent will the coordinates in the -c
     file be used.  Note that these velocities will not be used when  gen_vel  =
     yes  in  your  .mdp  file.  An  energy file can be supplied with -e to read
     Nose-Hoover and/or Parrinello-Rahman coupling variables.

     gmx grompp can be used to restart simulations  (preserving  continuity)  by
     supplying just a checkpoint file with -t.	However, for simply changing the
     number  of  run steps to extend a run, using gmx convert-tpr is more conve-
     nient than gmx grompp.  You then supply the old checkpoint file directly to
     gmx mdrun with -cpi. If you wish to change the ensemble or things like out-
     put frequency, then supplying the checkpoint file to  gmx	grompp	with  -t
     along  with  a new .mdp file with -f is the recommended procedure. Actually
     preserving the ensemble (if possible) still requires passing the checkpoint
     file to gmx mdrun -cpi.

     By default, all bonded interactions which have constant energy due to  vir-
     tual  site  constructions	will  be removed. If this constant energy is not
     zero, this will result in a shift in the total energy. All bonded	interac-
     tions  can  be  kept by turning off -rmvsbds. Additionally, all constraints
     for distances which will be constant anyway because of  virtual  site  con-
     structions will be removed. If any constraints remain which involve virtual
     sites, a fatal error will result.

     To  verify  your  run  input  file, please take note of all warnings on the
     screen, and correct where necessary. Do also look at the  contents  of  the
     mdout.mdp	file; this contains comment lines, as well as the input that gmx
     grompp has read. If in doubt, you can start gmx grompp with the -debug  op-
     tion  which  will	give  you  more  information in a file called grompp.log
     (along with real debug info). You can see the contents  of  the  run  input
     file  with  the gmx dump program. gmx check can be used to compare the con-
     tents of two run input files.

     The -maxwarn option can be used to override warnings printed by gmx  grompp
     that  otherwise halt output. In some cases, warnings are harmless, but usu-
     ally they are not. The user is advised to carefully  interpret  the  output
     messages before attempting to bypass them with this option.

OPTIONS
     Options to specify input files:

     -f [<.mdp>] (grompp.mdp)
	    grompp input file with MD parameters

     -c [<.gro/.g96/...>] (conf.gro)
	    Structure file: gro g96 pdb brk ent esp tpr

     -r [<.gro/.g96/...>] (restraint.gro) (Optional)
	    Structure file: gro g96 pdb brk ent esp tpr

     -rb [<.gro/.g96/...>] (restraint.gro) (Optional)
	    Structure file: gro g96 pdb brk ent esp tpr

     -n [<.ndx>] (index.ndx) (Optional)
	    Index file

     -p [<.top>] (topol.top)
	    Topology file

     -t [<.trr/.cpt/...>] (traj.trr) (Optional)
	    Full precision trajectory: trr cpt tng h5md

     -e [<.edr>] (ener.edr) (Optional)
	    Energy file

     -qmi [<.inp>] (topol-qmmm.inp) (Optional)
	    Input file for QM program

     Options to specify input/output files:

     -ref [<.trr/.cpt/...>] (rotref.trr) (Optional)
	    Full precision trajectory: trr cpt tng h5md

     Options to specify output files:

     -po [<.mdp>] (mdout.mdp)
	    grompp input file with MD parameters

     -pp [<.top>] (processed.top) (Optional)
	    Topology file

     -o [<.tpr>] (topol.tpr)
	    Portable xdr run input file

     -imd [<.gro>] (imdgroup.gro) (Optional)
	    Coordinate file in Gromos-87 format

     Other options:

     -[no]v (no)
	    Be loud and noisy

     -time <real> (-1)
	    Take frame at or first after this time.

     -[no]rmvsbds (yes)
	    Remove constant bonded interactions with virtual sites

     -maxwarn <int> (0)
	    Number  of	allowed warnings during input processing. Not for normal
	    use and may generate unstable systems

     -[no]zero (no)
	    Set parameters for bonded interactions without defaults to zero  in-
	    stead of generating an error

     -[no]renum (yes)
	    Renumber atomtypes and minimize number of atomtypes

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			   GMX-GROMPP(1)

home | help